# maysics
本库用于科学计算和快速建模

maysics主要包括十三个模块：<br/>
1、algorithm 封装了几种算法，用于简易模拟；<br/>
2、calculus 封装了常见的算符算子，辅助数学运算；<br/>
3、constant 储存了部分常数；<br/>
4、equation 封装了部分方程求解方法；<br/>
5、explainer 用于评估和解释模型；<br/>
6、graph 用于图论分析；<br/>
7、imageprocess 用于数字图像处理;<br/>
8、models 封装了几种常用的模型以便快速构建数理模型；<br/>
9、preprocess 用于数据预处理；<br/>
10、stats 用于统计分析；<br/>
11、tprocess 用于处理时间数据；<br/>
12、transformation 封装了常用的坐标转换及其他数学变换；<br/>
13、utils 是额外工具箱。<br/>


This package is used for scientific calculating and fast modeling

maysics includes thirteen modules:<br/>
1. "algorithm" packages several algorithms for simple simulation;<br/>
2. "calculus" packaes common operatoes;<br/>
3. "constant" stores common constants;<br/>
4. "equation" packages some equation solving operation;<br/>
5. "explainer" is used for estimating and explaining models;<br/>
6. "graph" is used for graph theory analysis;<br/>
7. "imageprocess" is used for digital image process;<br/>
7. "models" packages several coommon models for fast modeling;<br/>
8. "preprocess" is used for data preproccessing;<br/>
9. "stats" is uesd for statistical analysis;<br/>
10. "tprocess" is used for processing time data;<br/>
11. "transformation" packages common coordinate transformations and other mathematical transformations;<br/>
12. "utils" is extra Utils.